<?php
/**
 * @var \App\View\AppView $this
 * @var \App\Model\Entity\Contract $contract
 * @var string[]|\Cake\Collection\CollectionInterface $customers
 * @var string[]|\Cake\Collection\CollectionInterface $serviceTypes
 * @var string[]|\Cake\Collection\CollectionInterface $installationAddresses
 * @var string[]|\Cake\Collection\CollectionInterface $accessPoints
 */

use Cake\I18n\FrozenDate;
?>
<div class="row">
    <aside class="column">
        <div class="side-nav">
            <h4 class="heading"><?= __('Actions') ?></h4>
            <?= $this->AuthLink->link(__('List Contracts'), ['action' => 'index'], ['class' => 'side-nav-item']) ?>
        </div>
    </aside>
    <div class="column-responsive column-90">
        <div class="contracts form content">
            <?= $this->Form->create($contract) ?>
            <fieldset>
                <legend><?= __('Add Contract') ?></legend>
                <?php
                if (!isset($customer_id)) {
                    echo $this->Form->control('customer_id', ['options' => $customers, 'empty' => true]);
                }
                echo $this->Form->control('service_type_id', ['options' => $serviceTypes, 'empty' => true]);
                echo $this->Form->control('installation_address_id', [
                    'options' => $installationAddresses,
                    'empty' => true,
                ]);
                echo $this->Form->control('access_point_id', ['options' => $accessPoints, 'empty' => true]);
                echo $this->Form->control('valid_from', ['empty' => true]);

                echo $this->Form->control('enable_valid_until', [
                    'label' => false,
                    'type' => 'checkbox',
                    'templates' => [
                        'inputContainer' => '<div class="float-left">{{content}}&nbsp;</div>',
                    ],
                    'onclick' => 'document.getElementById("valid-until").disabled = !this.checked;',
                ]);
                echo $this->Form->hidden('valid_until', ['value' => '']); //return null if not enabled
                echo $this->Form->control('valid_until', [
                    'empty' => true,
                    'disabled' => !$contract->has('valid_until'),
                ]);
                $this->Form->unlockField('valid_until'); //disable form security check

                echo $this->Form->control('enable_obligation_until', [
                    'label' => false,
                    'type' => 'checkbox',
                    'templates' => [
                        'inputContainer' => '<div class="float-left">{{content}}&nbsp;</div>',
                    ],
                    'onclick' => 'document.getElementById("obligation-until").disabled = !this.checked;',
                ]);
                echo $this->Form->hidden('obligation_until', ['value' => '']); //return null if not enabled
                echo $this->Form->control('obligation_until', [
                    'empty' => true,
                    'disabled' => !$contract->has('obligation_until'),
                    'default' => FrozenDate::now()->addMonth(24)->lastOfMonth(),
                ]);
                $this->Form->unlockField('obligation_until'); //disable form security check

                echo $this->Form->control('note');
                ?>
            </fieldset>
            <?= $this->Form->button(__('Submit')) ?>
            <?= $this->Form->end() ?>
        </div>
    </div>
</div>
